@@ -64,15 +64,14 @@ class jkAbstractProtocol(AbstractProtocol):
             "getInfo",
         ]
         self.DEFAULT_COMMAND = "getInfo"
+        self.ID_COMMANDS = None
 
     def get_full_command(self, command) -> bytes:
         """
         Override the default get_full_command as its different for JK
         """
         # getInfo = b'\xaa\x55\x90\xeb\x97\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x11'
-        log.info(
-            f"Using protocol {self._protocol_id} with {len(self.COMMANDS)} commands"
-        )
+        log.info(f"Using protocol {self._protocol_id} with {len(self.COMMANDS)} commands")
         # These need to be set to allow other functions to work`
         self._command = command
         self._command_defn = self.get_command_defn(command)
@@ -114,10 +113,7 @@ class jkAbstractProtocol(AbstractProtocol):
         Override the default get_responses as its different for JK
         """
         responses = []
-        if (
-            self._command_defn is not None
-            and self._command_defn["response_type"] == "POSITIONAL"
-        ):
+        if self._command_defn is not None and self._command_defn["response_type"] == "POSITIONAL":
             # Have a POSITIONAL type response, so need to break it up...
             # example defn :
             # "response": [
