@@ -11,7 +11,7 @@ QUERY_COMMANDS = {
         "help": " -- queries the device serial number (length greater than 14)",
         "type": "QUERY",
         "response_type": "INDEXED",
-        "response": [[1, "Serial Number", "bytes.decode:r[2:int(r[0:2])+2]", ""]],
+        "response": [[1, "Serial Number", "bytes.decode:r[2:int(r[0:2])+2]", "", {"icon": "mdi:identifier"}]],
         "test_responses": [
             b"(1492932105105335005535\x94\x0e\r",
         ],
@@ -20,37 +20,70 @@ QUERY_COMMANDS = {
         "name": "QVFW3",
         "description": "Remote CPU firmware version inquiry",
         "type": "QUERY",
-        "response": [["string", "Remote CPU firmware version", ""]],
+        "response_type": "INDEXED",
+        "response": [[1, "Remote CPU firmware version", "bytes.decode", "", {"icon": "mdi:identifier"}]],
         "test_responses": [],
     },
     "VERFW": {
         "name": "VERFW",
         "description": "Bluetooth version inquiry",
         "type": "QUERY",
-        "response": [["string", "Bluetooth version", ""]],
+        "response_type": "INDEXED",
+        "response": [[1, "Bluetooth version", "bytes.decode", "", {"icon": "mdi:identifier"}]],
         "test_responses": [],
     },
     "QPIRI": {
         "name": "QPIRI",
         "description": "Current Settings inquiry",
         "type": "QUERY",
-        "response_type": "SEQUENTIAL",
+        "response_type": "INDEXED",
         "response": [
-            ["float", "AC Input Voltage", "V"],
-            ["float", "AC Input Current", "A"],
-            ["float", "AC Output Voltage", "V"],
-            ["float", "AC Output Frequency", "Hz"],
-            ["float", "AC Output Current", "A"],
-            ["int", "AC Output Apparent Power", "VA"],
-            ["int", "AC Output Active Power", "W"],
-            ["float", "Battery Voltage", "V"],
-            ["float", "Battery Recharge Voltage", "V"],
-            ["float", "Battery Under Voltage", "V"],
-            ["float", "Battery Bulk Charge Voltage", "V"],
-            ["float", "Battery Float Charge Voltage", "V"],
             [
-                "option",
+                1,
+                "AC Input Voltage",
+                "float",
+                "V",
+                {"icon": "mdi:transmission-tower-import", "device-class": "voltage"},
+            ],
+            [2, "AC Input Current", "float", "A", {"icon": "mdi:current-ac", "device-class": "current"}],
+            [
+                3,
+                "AC Output Voltage",
+                "float",
+                "V",
+                {"icon": "mdi:transmission-tower-export", "device-class": "voltage"},
+            ],
+            [4, "AC Output Frequency", "float", "Hz", {"icon": "mdi:current-ac", "device-class": "frequency"}],
+            [5, "AC Output Current", "float", "A", {"icon": "mdi:current-ac", "device-class": "current"}],
+            [6, "AC Output Apparent Power", "int", "VA", {"icon": "mdi:power-plug", "device-class": "apparent_power"}],
+            [
+                7,
+                "AC Output Active Power",
+                "int",
+                "W",
+                {"icon": "mdi:power-plug", "device-class": "power", "state_class": "measurement"},
+            ],
+            [8, "Battery Voltage", "float", "V", {"icon": "mdi:battery-outline", "device-class": "voltage"}],
+            [9, "Battery Recharge Voltage", "float", "V", {"icon": "mdi:battery-outline", "device-class": "voltage"}],
+            [10, "Battery Under Voltage", "float", "V", {"icon": "mdi:battery-outline", "device-class": "voltage"}],
+            [
+                11,
+                "Battery Bulk Charge Voltage",
+                "float",
+                "V",
+                {"icon": "mdi:battery-outline", "device-class": "voltage"},
+            ],
+            [
+                12,
+                "Battery Float Charge Voltage",
+                "float",
+                "V",
+                {"icon": "mdi:battery-outline", "device-class": "voltage"},
+            ],
+            [
+                13,
                 "Battery Type",
+                "option",
                 [
                     "AGM",
                     "Flooded",
@@ -63,12 +96,13 @@ QUERY_COMMANDS = {
                     "3rd party Lithium",
                 ],
             ],
-            ["int", "Max AC Charging Current", "A"],
-            ["int", "Max Charging Current", "A"],
-            ["option", "Input Voltage Range", ["Appliance", "UPS"]],
+            [14, "Max AC Charging Current", "int", "A", {"icon": "mdi:current-ac", "device-class": "current"}],
+            [15, "Max Charging Current", "int", "A", {"icon": "mdi:current-ac", "device-class": "current"}],
+            [16, "Input Voltage Range", "option", ["Appliance", "UPS"]],
             [
-                "option",
+                17,
                 "Output Source Priority",
+                "option",
                 [
                     "Utility Solar Battery",
                     "Solar Utility Battery",
@@ -76,8 +110,9 @@ QUERY_COMMANDS = {
                 ],
             ],
             [
-                "option",
+                18,
                 "Charger Source Priority",
+                "option",
                 [
                     "Utility first",
                     "Solar first",
@@ -85,16 +120,18 @@ QUERY_COMMANDS = {
                     "Only solar charging permitted",
                 ],
             ],
-            ["int", "Max Parallel Units", "units"],
+            [19, "Max Parallel Units", "int", "units"],
             [
-                "str_keyed",
+                20,
                 "Machine Type",
+                "str_keyed",
                 {"00": "Grid tie", "01": "Off Grid", "10": "Hybrid"},
             ],
-            ["option", "Topology", ["transformerless", "transformer"]],
+            [21, "Topology", "option", ["transformerless", "transformer"]],
             [
-                "option",
+                22,
                 "Output Mode",
+                "option",
                 [
                     "single machine output",
                     "parallel output",
@@ -107,32 +144,37 @@ QUERY_COMMANDS = {
                     "unknown output",
                 ],
             ],
-            ["float", "Battery Redischarge Voltage", "V"],
+            [23, "Battery Redischarge Voltage", "float", "V"],
             [
-                "option",
+                24,
                 "PV OK Condition",
+                "option",
                 [
                     "As long as one unit of inverters has connect PV, parallel system will consider PV OK",
                     "Only All of inverters have connect PV, parallel system will consider PV OK",
                 ],
             ],
             [
-                "option",
+                25,
                 "PV Power Balance",
+                "option",
                 [
                     "PV input max current will be the max charged current",
                     "PV input max power will be the sum of the max charged power and loads power",
                 ],
             ],
-            ["int", "Max charging time for CV stage", "min"],
+            [26, "Max charging time for CV stage", "int", "min"],
             [
-                "option",
+                27,
                 "Operation Logic",
+                "option",
                 ["Automatic mode", "On-line mode", "ECO mode"],
             ],
-            ["int", "Max discharging current", "A"],
+            [28, "Max discharging current", "int", "A", {"icon": "mdi:current-ac", "device-class": "current"}],
+        ],
+        "test_responses": [
+            b"(230.0 21.7 230.0 50.0 21.7 5000 4000 48.0 46.0 42.0 56.4 54.0 0 10 010 1 0 0 6 01 0 0 54.0 0 1\x6F\x7E\r",
         ],
-        "test_responses": [],
     },
     "QFLAG": {
         "name": "QFLAG",
@@ -172,13 +214,19 @@ QUERY_COMMANDS = {
                 "AC Input Voltage",
                 "float",
                 "V",
-                {"icon": "mdi:transmission-tower-export"},
+                {"icon": "mdi:transmission-tower-export", "device-class": "voltage"},
             ],
             [2, "AC Input Frequency", "float", "Hz", {"icon": "mdi:current-ac", "device-class": "frequency"}],
             [3, "AC Output Voltage", "float", "V", {"icon": "mdi:power-plug", "device-class": "voltage"}],
             [4, "AC Output Frequency", "float", "Hz", {"icon": "mdi:current-ac", "device-class": "frequency"}],
             [5, "AC Output Apparent Power", "int", "VA", {"icon": "mdi:power-plug", "device-class": "apparent_power"}],
-            [6, "AC Output Active Power", "int", "W", {"icon": "mdi:power-plug", "device-class": "power"}],
+            [
+                6,
+                "AC Output Active Power",
+                "int",
+                "W",
+                {"icon": "mdi:power-plug", "device-class": "power", "state_class": "measurement"},
+            ],
             [7, "AC Output Load", "int", "%", {"icon": "mdi:brightness-percent"}],
             [8, "BUS Voltage", "int", "V", {"icon": "mdi:details", "device-class": "voltage"}],
             [9, "Battery Voltage", "float", "V", {"icon": "mdi:battery-outline", "device-class": "voltage"}],
@@ -224,7 +272,13 @@ QUERY_COMMANDS = {
             ],
             [18, "Battery Voltage Offset for Fans On", "int", "10mV"],
             [19, "EEPROM Version", "int", ""],
-            [20, "PV1 Charging Power", "int", "W", {"icon": "mdi:solar-power", "device-class": "power"}],
+            [
+                20,
+                "PV1 Charging Power",
+                "int",
+                "W",
+                {"icon": "mdi:solar-power", "device-class": "power", "state_class": "measurement"},
+            ],
             [
                 21,
                 "Device Status2",
@@ -242,7 +296,13 @@ QUERY_COMMANDS = {
                     "02": "South America",
                 },
             ],
-            [24, "Solar Feed to Grid Power", "int", "W"],
+            [
+                24,
+                "Solar Feed to Grid Power",
+                "int",
+                "W",
+                {"icon": "mdi:solar-power", "device-class": "power", "state_class": "measurement"},
+            ],
         ],
         "test_responses": [
             b"(227.2 50.0 230.3 50.0 0829 0751 010 447 54.50 020 083 0054 02.7 323.6 00.00 00000 00010110 00 00 00879 010\xf1\x8c\r",
@@ -256,7 +316,13 @@ QUERY_COMMANDS = {
         "response": [
             [1, "PV2 Input Current", "float", "A", {"icon": "mdi:solar-power", "device-class": "current"}],
             [2, "PV2 Input Voltage", "float", "V", {"icon": "mdi:solar-power", "device-class": "voltage"}],
-            [3, "PV2 Charging Power", "int", "W", {"icon": "mdi:solar-power", "device-class": "power"}],
+            [
+                3,
+                "PV2 Charging Power",
+                "int",
+                "W",
+                {"icon": "mdi:solar-power", "device-class": "power", "state_class": "measurement"},
+            ],
         ],
         "test_responses": [
             b"(03.1 327.3 01026 \xc9\x8b\r",
@@ -329,7 +395,13 @@ QUERY_COMMANDS = {
             [7, "AC Output Voltage", "float", "V", {"icon": "mdi:power-plug", "device-class": "voltage"}],
             [8, "AC Output Frequency", "float", "Hz", {"icon": "mdi:current-ac", "device-class": "frequency"}],
             [9, "AC Output Apparent Power", "int", "VA", {"icon": "mdi:power-plug", "device-class": "apparent_power"}],
-            [10, "AC Output Active Power", "int", "W", {"icon": "mdi:power-plug", "device-class": "power"}],
+            [
+                10,
+                "AC Output Active Power",
+                "int",
+                "W",
+                {"icon": "mdi:power-plug", "device-class": "power", "state_class": "measurement"},
+            ],
             [11, "Load Percentage", "int", "%", {"icon": "mdi:brightness-percent"}],
             [12, "Battery Voltage", "float", "V", {"icon": "mdi:battery-outline", "device-class": "voltage"}],
             [13, "Battery Charging Current", "int", "A", {"icon": "mdi:current-dc", "device-class": "current"}],
@@ -349,7 +421,13 @@ QUERY_COMMANDS = {
                 "VA",
                 {"icon": "mdi:power-plug", "device-class": "apparent_power"},
             ],
-            [18, "Total Output Active Power", "int", "W", {"icon": "mdi:power-plug", "device-class": "power"}],
+            [
+                18,
+                "Total Output Active Power",
+                "int",
+                "W",
+                {"icon": "mdi:power-plug", "device-class": "power", "state_class": "measurement"},
+            ],
             [
                 19,
                 "Total AC Output Percentage",
@@ -417,10 +495,12 @@ QUERY_COMMANDS = {
         "name": "QMOD",
         "description": "Mode inquiry",
         "type": "QUERY",
+        "response_type": "INDEXED",
         "response": [
             [
-                "keyed",
+                1,
                 "Device Mode",
+                "str_keyed",
                 {
                     "P": "Power on",
                     "S": "Standby",
@@ -433,7 +513,7 @@ QUERY_COMMANDS = {
             ]
         ],
         "test_responses": [
-            b"(S\x64\x39\r",
+            b"(S\xe5\xd9\r",
             b"(B\xe7\xc9\r",
         ],
     },
@@ -778,7 +858,14 @@ QUERY_COMMANDS = {
         "description": "Total PV Generated Energy Inquiry",
         "type": "QUERY",
         "response_type": "SEQUENTIAL",
-        "response": [["int", "Total PV Generated Energy", "Wh"]],
+        "response": [
+            [
+                "int",
+                "Total PV Generated Energy",
+                "Wh",
+                {"icon": "mdi:solar-power", "device-class": "energy", "state_class": "total"},
+            ]
+        ],
         "test_responses": [
             b"(00238800!J\r",
         ],
@@ -789,7 +876,12 @@ QUERY_COMMANDS = {
         "type": "QUERY",
         "response_type": "SEQUENTIAL",
         "response": [
-            ["int", "PV Generated Energy for Year", "Wh"],
+            [
+                "int",
+                "PV Generated Energy for Year",
+                "Wh",
+                {"icon": "mdi:counter", "device-class": "energy", "state_class": "total"},
+            ],
             ["info:cv", "Year", ""],
         ],
         "test_responses": [
@@ -803,7 +895,12 @@ QUERY_COMMANDS = {
         "type": "QUERY",
         "response_type": "SEQUENTIAL",
         "response": [
-            ["int", "PV Generated Energy for Month", "Wh"],
+            [
+                "int",
+                "PV Generated Energy for Month",
+                "Wh",
+                {"icon": "mdi:solar-power", "device-class": "energy", "state_class": "total"},
+            ],
             ["info:cv[:4]", "Year", ""],
             ["info:calendar.month_name[int(cv[4:])]", "Month", ""],
         ],
@@ -819,7 +916,13 @@ QUERY_COMMANDS = {
         "type": "QUERY",
         "response_type": "INDEXED",
         "response": [
-            [1, "PV Generated Energy for Day", "int", "Wh", {"icon": "mdi:solar-power", "device-class": "energy"}],
+            [
+                1,
+                "PV Generated Energy for Day",
+                "int",
+                "Wh",
+                {"icon": "mdi:solar-power", "device-class": "energy", "state_class": "total"},
+            ],
             [2, "Year", "info:cv[:4]", ""],
             [3, "Month", "info:calendar.month_name[int(cv[4:6])]", ""],
             [4, "Day", "info:cv[6:]", ""],
@@ -834,7 +937,14 @@ QUERY_COMMANDS = {
         "description": "Total Output Load Energy Inquiry",
         "type": "QUERY",
         "response_type": "SEQUENTIAL",
-        "response": [["int", "Total Output Load Energy", "Wh"]],
+        "response": [
+            [
+                "int",
+                "Total Output Load Energy",
+                "Wh",
+                {"icon": "mdi:counter", "device-class": "energy", "state_class": "total"},
+            ]
+        ],
         "test_responses": [
             b"(00238800!J\r",
         ],
@@ -845,7 +955,12 @@ QUERY_COMMANDS = {
         "type": "QUERY",
         "response_type": "SEQUENTIAL",
         "response": [
-            ["int", "Output Load Energy for Year", "Wh"],
+            [
+                "int",
+                "Output Load Energy for Year",
+                "Wh",
+                {"icon": "mdi:counter", "device-class": "energy", "state_class": "total"},
+            ],
             ["info:cv", "Year", ""],
         ],
         "test_responses": [
@@ -859,7 +974,12 @@ QUERY_COMMANDS = {
         "type": "QUERY",
         "response_type": "SEQUENTIAL",
         "response": [
-            ["int", "Output Load Energy for Month", "Wh"],
+            [
+                "int",
+                "Output Load Energy for Month",
+                "Wh",
+                {"icon": "mdi:counter", "device-class": "energy", "state_class": "total"},
+            ],
             ["info:cv[:4]", "Year", ""],
             ["info:calendar.month_name[int(cv[4:])]", "Month", ""],
         ],
@@ -874,7 +994,12 @@ QUERY_COMMANDS = {
         "type": "QUERY",
         "response_type": "SEQUENTIAL",
         "response": [
-            ["int", "Output Load Energy for Day", "Wh"],
+            [
+                "int",
+                "Output Load Energy for Day",
+                "Wh",
+                {"icon": "mdi:counter", "device-class": "energy", "state_class": "total"},
+            ],
             ["info:cv[:4]", "Year", ""],
             ["info:calendar.month_name[int(cv[4:6])]", "Month", ""],
             ["info:cv[6:]", "Day", ""],
